@@ -8,8 +8,7 @@
   * the Free Software Foundation; either version 2 of the License, or
   * (at your option) any later version.
   * 
-  * T
-his program is distributed in the hope that it will be useful,
+  * This program is distributed in the hope that it will be useful,
   * but WITHOUT ANY WARRANTY; without even the implied warranty of
   * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   * GNU General Public License for more details.
@@ -30,10 +29,6 @@ his program is distributed in the hope that it will be useful,
 #include <sys/wait.h>
 #include <errno.h>
 
-#include <gnome.h>
-
-#include <libgnomeui/gnome-window-icon.h>
-
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/resources.h>
 #include <libanjuta/interfaces/ianjuta-preferences.h>
@@ -43,12 +38,14 @@ his program is distributed in the hope that it will be useful,
 #include "action-callbacks.h"
 #include "anjuta.h"
 
+#define TOOLBAR_VISIBLE "toolbar-visible"
+
 void
 on_exit1_activate (GtkAction * action, AnjutaApp *app)
 {
 	GdkEvent *event = gdk_event_new (GDK_DELETE);
 
-	event->any.window = g_object_ref (GTK_WIDGET(app)->window);
+	event->any.window = g_object_ref (gtk_widget_get_window (GTK_WIDGET(app)));
 	event->any.send_event = TRUE;
   
 	gtk_main_do_event (event);
@@ -79,6 +76,23 @@ on_reset_layout_activate(GtkAction *action, AnjutaApp *app)
 	anjuta_app_layout_reset (app);
 }
 
+void
+on_toolbar_view_toggled (GtkAction *action, AnjutaApp *app)
+{
+	gboolean status = gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(action));
+	if (status)
+	{
+		gtk_widget_show (app->toolbar);
+	}
+	else
+	{
+		gtk_widget_hide (app->toolbar);
+	}
+	g_settings_set_boolean (app->settings,
+	                        TOOLBAR_VISIBLE,
+	                        status);
+}
+
 void
 on_set_preferences1_activate (GtkAction * action, AnjutaApp *app)
 {
@@ -107,36 +121,39 @@ on_set_preferences1_activate (GtkAction * action, AnjutaApp *app)
 }
 
 static void
-help_activate (const gchar *doc_id, const gchar *item)
+help_activate (GtkWidget *parent, const gchar *doc_id, const gchar *item)
 {
-	if (gnome_help_display_with_doc_id (NULL, doc_id, item, NULL, NULL) == FALSE)
-	{
-	  anjuta_util_dialog_error (NULL, _("Unable to display help. Please make sure Anjuta documentation package is install. It can be downloaded from http://anjuta.org"));	
-	}
+	anjuta_util_help_display (parent, doc_id, item);
 }
 
 void
 on_help_manual_activate (GtkAction *action, gpointer data)
 {
-	help_activate ("anjuta-manual", "anjuta-manual.xml");
+	help_activate (data, "anjuta-manual", "anjuta-manual.xml");
 }
 
 void
 on_help_tutorial_activate (GtkAction *action, gpointer data)
 {
-	help_activate ("anjuta-tutorial", "anjuta-tutorial.xml");
+	help_activate (data, "anjuta-tutorial", "anjuta-tutorial.xml");
 }
 
 void
 on_help_advanced_tutorial_activate (GtkAction *action, gpointer data)
 {
-	help_activate ("anjuta-advanced-tutorial", "anjuta-advanced-tutorial.xml");
+	help_activate (data, "anjuta-advanced-tutorial", "anjuta-advanced-tutorial.xml");
 }
 
 void
 on_help_faqs_activate (GtkAction *action, gpointer data)
 {
-	help_activate ("anjuta-faqs", "anjuta-faqs.xml");
+	GError* error = NULL;
+	if (!g_spawn_command_line_async ("yelp ghelp:anjuta-faqs", &error) &&
+	    error)
+	{
+		g_warning ("Could open FAQ: %s", error->message);
+		g_error_free (error);
+	}
 }
 
 void
@@ -148,7 +165,7 @@ on_url_home_activate (GtkAction * action, gpointer user_data)
 void
 on_url_bugs_activate (GtkAction * action, gpointer user_data)
 {
-	anjuta_res_url_show("http://bugzilla.gnome.org/simple-bug-guide.cgi");
+	anjuta_res_url_show("https://bugzilla.gnome.org/enter_bug.cgi?product=anjuta");
 }
 
 void
